@@ -15,3 +15,6 @@ setGeneric("coef",function(object,...)standardGeneric("coef"))
 setGeneric("logLik",function(object,...)standardGeneric("logLik"))
 setGeneric("window",function(x,...)standardGeneric("window"))
 setGeneric("continue",function(object,...)standardGeneric("continue"))
+setGeneric("pred.mean",function(object,...)standardGeneric("pred.mean"))
+setGeneric("pred.var",function(object,...)standardGeneric("pred.var"))
+setGeneric("filter.mean",function(object,...)standardGeneric("filter.mean"))
